==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewayProbeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewayProbeArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ApplicationGatewayProtocol
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Probe of the application gateway.
 * @property host Host name to send the probe to.
 * @property id Resource ID.
 * @property interval The probing interval in seconds. This is the time interval between two consecutive probes. Acceptable values are from 1 second to 86400 seconds.
 * @property match Criterion for classifying a healthy probe response.
 * @property minServers Minimum number of servers that are always marked healthy. Default value is 0.
 * @property name Name of the probe that is unique within an Application Gateway.
 * @property path Relative path of probe. Valid path starts from '/'. Probe is sent to <Protocol>://<host>:<port><path>.
 * @property pickHostNameFromBackendHttpSettings Whether the host header should be picked from the backend http settings. Default value is false.
 * @property pickHostNameFromBackendSettings Whether the server name indication should be picked from the backend settings for Tls protocol. Default value is false.
 * @property port Custom port which will be used for probing the backend servers. The valid value ranges from 1 to 65535. In case not set, port from http settings will be used. This property is valid for Standard_v2 and WAF_v2 only.
 * @property protocol The protocol used for the probe.
 * @property timeout The probe timeout in seconds. Probe marked as failed if valid response is not received with this timeout period. Acceptable values are from 1 second to 86400 seconds.
 * @property unhealthyThreshold The probe retry count. Backend server is marked down after consecutive probe failure count reaches UnhealthyThreshold. Acceptable values are from 1 second to 20.
 */
public data class ApplicationGatewayProbeArgs(
    public val host: Output<String>? = null,
    public val id: Output<String>? = null,
    public val interval: Output<Int>? = null,
    public val match: Output<ApplicationGatewayProbeHealthResponseMatchArgs>? = null,
    public val minServers: Output<Int>? = null,
    public val name: Output<String>? = null,
    public val path: Output<String>? = null,
    public val pickHostNameFromBackendHttpSettings: Output<Boolean>? = null,
    public val pickHostNameFromBackendSettings: Output<Boolean>? = null,
    public val port: Output<Int>? = null,
    public val protocol: Output<Either<String, ApplicationGatewayProtocol>>? = null,
    public val timeout: Output<Int>? = null,
    public val unhealthyThreshold: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewayProbeArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ApplicationGatewayProbeArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewayProbeArgs.builder()
            .host(host?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .interval(interval?.applyValue({ args0 -> args0 }))
            .match(match?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .minServers(minServers?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .path(path?.applyValue({ args0 -> args0 }))
            .pickHostNameFromBackendHttpSettings(
                pickHostNameFromBackendHttpSettings?.applyValue({ args0 ->
                    args0
                }),
            )
            .pickHostNameFromBackendSettings(pickHostNameFromBackendSettings?.applyValue({ args0 -> args0 }))
            .port(port?.applyValue({ args0 -> args0 }))
            .protocol(
                protocol?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .timeout(timeout?.applyValue({ args0 -> args0 }))
            .unhealthyThreshold(unhealthyThreshold?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApplicationGatewayProbeArgs].
 */
@PulumiTagMarker
public class ApplicationGatewayProbeArgsBuilder internal constructor() {
    private var host: Output<String>? = null

    private var id: Output<String>? = null

    private var interval: Output<Int>? = null

    private var match: Output<ApplicationGatewayProbeHealthResponseMatchArgs>? = null

    private var minServers: Output<Int>? = null

    private var name: Output<String>? = null

    private var path: Output<String>? = null

    private var pickHostNameFromBackendHttpSettings: Output<Boolean>? = null

    private var pickHostNameFromBackendSettings: Output<Boolean>? = null

    private var port: Output<Int>? = null

    private var protocol: Output<Either<String, ApplicationGatewayProtocol>>? = null

    private var timeout: Output<Int>? = null

    private var unhealthyThreshold: Output<Int>? = null

    /**
     * @param value Host name to send the probe to.
     */
    @JvmName("pligviycvqwptlih")
    public suspend fun host(`value`: Output<String>) {
        this.host = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("bcrqsjvifisavevl")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The probing interval in seconds. This is the time interval between two consecutive probes. Acceptable values are from 1 second to 86400 seconds.
     */
    @JvmName("kcdggecrgniqcdlk")
    public suspend fun interval(`value`: Output<Int>) {
        this.interval = value
    }

    /**
     * @param value Criterion for classifying a healthy probe response.
     */
    @JvmName("gwbvcocffvpxmopt")
    public suspend fun match(`value`: Output<ApplicationGatewayProbeHealthResponseMatchArgs>) {
        this.match = value
    }

    /**
     * @param value Minimum number of servers that are always marked healthy. Default value is 0.
     */
    @JvmName("qtpxrcybsiravjnd")
    public suspend fun minServers(`value`: Output<Int>) {
        this.minServers = value
    }

    /**
     * @param value Name of the probe that is unique within an Application Gateway.
     */
    @JvmName("wqrkfntgmmanyotg")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Relative path of probe. Valid path starts from '/'. Probe is sent to <Protocol>://<host>:<port><path>.
     */
    @JvmName("fnhactawrxothkud")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value Whether the host header should be picked from the backend http settings. Default value is false.
     */
    @JvmName("frxusgaammgukvfq")
    public suspend fun pickHostNameFromBackendHttpSettings(`value`: Output<Boolean>) {
        this.pickHostNameFromBackendHttpSettings = value
    }

    /**
     * @param value Whether the server name indication should be picked from the backend settings for Tls protocol. Default value is false.
     */
    @JvmName("fwkfpuigbjqulxit")
    public suspend fun pickHostNameFromBackendSettings(`value`: Output<Boolean>) {
        this.pickHostNameFromBackendSettings = value
    }

    /**
     * @param value Custom port which will be used for probing the backend servers. The valid value ranges from 1 to 65535. In case not set, port from http settings will be used. This property is valid for Standard_v2 and WAF_v2 only.
     */
    @JvmName("gvmsnxxrjrhnkrbx")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value The protocol used for the probe.
     */
    @JvmName("holqewlqcfkckede")
    public suspend fun protocol(`value`: Output<Either<String, ApplicationGatewayProtocol>>) {
        this.protocol = value
    }

    /**
     * @param value The probe timeout in seconds. Probe marked as failed if valid response is not received with this timeout period. Acceptable values are from 1 second to 86400 seconds.
     */
    @JvmName("frctresothlkntlh")
    public suspend fun timeout(`value`: Output<Int>) {
        this.timeout = value
    }

    /**
     * @param value The probe retry count. Backend server is marked down after consecutive probe failure count reaches UnhealthyThreshold. Acceptable values are from 1 second to 20.
     */
    @JvmName("sceadowkpgvckaxp")
    public suspend fun unhealthyThreshold(`value`: Output<Int>) {
        this.unhealthyThreshold = value
    }

    /**
     * @param value Host name to send the probe to.
     */
    @JvmName("jlvsvocxxfxsaitl")
    public suspend fun host(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.host = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("uhejeicaemqqqvxi")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The probing interval in seconds. This is the time interval between two consecutive probes. Acceptable values are from 1 second to 86400 seconds.
     */
    @JvmName("lmgkfnkuxikcbxhg")
    public suspend fun interval(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.interval = mapped
    }

    /**
     * @param value Criterion for classifying a healthy probe response.
     */
    @JvmName("bvfyebtfjfcakoug")
    public suspend fun match(`value`: ApplicationGatewayProbeHealthResponseMatchArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.match = mapped
    }

    /**
     * @param argument Criterion for classifying a healthy probe response.
     */
    @JvmName("wsdeyafwuvdyygoy")
    public suspend
    fun match(argument: suspend ApplicationGatewayProbeHealthResponseMatchArgsBuilder.() -> Unit) {
        val toBeMapped = ApplicationGatewayProbeHealthResponseMatchArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.match = mapped
    }

    /**
     * @param value Minimum number of servers that are always marked healthy. Default value is 0.
     */
    @JvmName("avmmargmfueqsobw")
    public suspend fun minServers(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minServers = mapped
    }

    /**
     * @param value Name of the probe that is unique within an Application Gateway.
     */
    @JvmName("hwlbblylhfbsfxtw")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Relative path of probe. Valid path starts from '/'. Probe is sent to <Protocol>://<host>:<port><path>.
     */
    @JvmName("couwwmouudujayxa")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value Whether the host header should be picked from the backend http settings. Default value is false.
     */
    @JvmName("pnwaemrmuodlspex")
    public suspend fun pickHostNameFromBackendHttpSettings(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pickHostNameFromBackendHttpSettings = mapped
    }

    /**
     * @param value Whether the server name indication should be picked from the backend settings for Tls protocol. Default value is false.
     */
    @JvmName("dbijnqimbejfyfdn")
    public suspend fun pickHostNameFromBackendSettings(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pickHostNameFromBackendSettings = mapped
    }

    /**
     * @param value Custom port which will be used for probing the backend servers. The valid value ranges from 1 to 65535. In case not set, port from http settings will be used. This property is valid for Standard_v2 and WAF_v2 only.
     */
    @JvmName("gwgcuycrdblxvfyq")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value The protocol used for the probe.
     */
    @JvmName("thmfxrypoblfbpkh")
    public suspend fun protocol(`value`: Either<String, ApplicationGatewayProtocol>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value The protocol used for the probe.
     */
    @JvmName("jvckivqyuvvdstcg")
    public fun protocol(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ApplicationGatewayProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value The protocol used for the probe.
     */
    @JvmName("iisntkemwqkkqkio")
    public fun protocol(`value`: ApplicationGatewayProtocol) {
        val toBeMapped = Either.ofRight<String, ApplicationGatewayProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value The probe timeout in seconds. Probe marked as failed if valid response is not received with this timeout period. Acceptable values are from 1 second to 86400 seconds.
     */
    @JvmName("yopuiymevrjqrrnh")
    public suspend fun timeout(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    /**
     * @param value The probe retry count. Backend server is marked down after consecutive probe failure count reaches UnhealthyThreshold. Acceptable values are from 1 second to 20.
     */
    @JvmName("jfpcsfmoqdbgcnvl")
    public suspend fun unhealthyThreshold(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.unhealthyThreshold = mapped
    }

    internal fun build(): ApplicationGatewayProbeArgs = ApplicationGatewayProbeArgs(
        host = host,
        id = id,
        interval = interval,
        match = match,
        minServers = minServers,
        name = name,
        path = path,
        pickHostNameFromBackendHttpSettings = pickHostNameFromBackendHttpSettings,
        pickHostNameFromBackendSettings = pickHostNameFromBackendSettings,
        port = port,
        protocol = protocol,
        timeout = timeout,
        unhealthyThreshold = unhealthyThreshold,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ApplicationGatewayProbeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ApplicationGatewayProbeArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ApplicationGatewayProtocol
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Probe of the application gateway.
 * @property host Host name to send the probe to.
 * @property id Resource ID.
 * @property interval The probing interval in seconds. This is the time interval between two consecutive probes. Acceptable values are from 1 second to 86400 seconds.
 * @property match Criterion for classifying a healthy probe response.
 * @property minServers Minimum number of servers that are always marked healthy. Default value is 0.
 * @property name Name of the probe that is unique within an Application Gateway.
 * @property path Relative path of probe. Valid path starts from '/'. Probe is sent to <Protocol>://<host>:<port><path>.
 * @property pickHostNameFromBackendHttpSettings Whether the host header should be picked from the backend http settings. Default value is false.
 * @property pickHostNameFromBackendSettings Whether the server name indication should be picked from the backend settings for Tls protocol. Default value is false.
 * @property port Custom port which will be used for probing the backend servers. The valid value ranges from 1 to 65535. In case not set, port from http settings will be used. This property is valid for Standard_v2 and WAF_v2 only.
 * @property protocol The protocol used for the probe.
 * @property timeout The probe timeout in seconds. Probe marked as failed if valid response is not received with this timeout period. Acceptable values are from 1 second to 86400 seconds.
 * @property unhealthyThreshold The probe retry count. Backend server is marked down after consecutive probe failure count reaches UnhealthyThreshold. Acceptable values are from 1 second to 20.
 */
public data class ApplicationGatewayProbeArgs(
    public val host: Output<String>? = null,
    public val id: Output<String>? = null,
    public val interval: Output<Int>? = null,
    public val match: Output<ApplicationGatewayProbeHealthResponseMatchArgs>? = null,
    public val minServers: Output<Int>? = null,
    public val name: Output<String>? = null,
    public val path: Output<String>? = null,
    public val pickHostNameFromBackendHttpSettings: Output<Boolean>? = null,
    public val pickHostNameFromBackendSettings: Output<Boolean>? = null,
    public val port: Output<Int>? = null,
    public val protocol: Output<Either<String, ApplicationGatewayProtocol>>? = null,
    public val timeout: Output<Int>? = null,
    public val unhealthyThreshold: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ApplicationGatewayProbeArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ApplicationGatewayProbeArgs =
        com.pulumi.azurenative.network.inputs.ApplicationGatewayProbeArgs.builder()
            .host(host?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .interval(interval?.applyValue({ args0 -> args0 }))
            .match(match?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .minServers(minServers?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .path(path?.applyValue({ args0 -> args0 }))
            .pickHostNameFromBackendHttpSettings(
                pickHostNameFromBackendHttpSettings?.applyValue({ args0 ->
                    args0
                }),
            )
            .pickHostNameFromBackendSettings(pickHostNameFromBackendSettings?.applyValue({ args0 -> args0 }))
            .port(port?.applyValue({ args0 -> args0 }))
            .protocol(
                protocol?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .timeout(timeout?.applyValue({ args0 -> args0 }))
            .unhealthyThreshold(unhealthyThreshold?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApplicationGatewayProbeArgs].
 */
@PulumiTagMarker
public class ApplicationGatewayProbeArgsBuilder internal constructor() {
    private var host: Output<String>? = null

    private var id: Output<String>? = null

    private var interval: Output<Int>? = null

    private var match: Output<ApplicationGatewayProbeHealthResponseMatchArgs>? = null

    private var minServers: Output<Int>? = null

    private var name: Output<String>? = null

    private var path: Output<String>? = null

    private var pickHostNameFromBackendHttpSettings: Output<Boolean>? = null

    private var pickHostNameFromBackendSettings: Output<Boolean>? = null

    private var port: Output<Int>? = null

    private var protocol: Output<Either<String, ApplicationGatewayProtocol>>? = null

    private var timeout: Output<Int>? = null

    private var unhealthyThreshold: Output<Int>? = null

    /**
     * @param value Host name to send the probe to.
     */
    @JvmName("lfkcetquppseuxhw")
    public suspend fun host(`value`: Output<String>) {
        this.host = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("nolsqhebtjpscmba")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The probing interval in seconds. This is the time interval between two consecutive probes. Acceptable values are from 1 second to 86400 seconds.
     */
    @JvmName("nqderopfxtqgnqpy")
    public suspend fun interval(`value`: Output<Int>) {
        this.interval = value
    }

    /**
     * @param value Criterion for classifying a healthy probe response.
     */
    @JvmName("nsofjufktwjgyesp")
    public suspend fun match(`value`: Output<ApplicationGatewayProbeHealthResponseMatchArgs>) {
        this.match = value
    }

    /**
     * @param value Minimum number of servers that are always marked healthy. Default value is 0.
     */
    @JvmName("skgsjhmimlpbflok")
    public suspend fun minServers(`value`: Output<Int>) {
        this.minServers = value
    }

    /**
     * @param value Name of the probe that is unique within an Application Gateway.
     */
    @JvmName("vyjgulefycghiufu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Relative path of probe. Valid path starts from '/'. Probe is sent to <Protocol>://<host>:<port><path>.
     */
    @JvmName("spbnyeeecanhmthp")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value Whether the host header should be picked from the backend http settings. Default value is false.
     */
    @JvmName("jwplfnecmlwbwoms")
    public suspend fun pickHostNameFromBackendHttpSettings(`value`: Output<Boolean>) {
        this.pickHostNameFromBackendHttpSettings = value
    }

    /**
     * @param value Whether the server name indication should be picked from the backend settings for Tls protocol. Default value is false.
     */
    @JvmName("olabtidyhpjucrex")
    public suspend fun pickHostNameFromBackendSettings(`value`: Output<Boolean>) {
        this.pickHostNameFromBackendSettings = value
    }

    /**
     * @param value Custom port which will be used for probing the backend servers. The valid value ranges from 1 to 65535. In case not set, port from http settings will be used. This property is valid for Standard_v2 and WAF_v2 only.
     */
    @JvmName("vulejtsuyacyvull")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value The protocol used for the probe.
     */
    @JvmName("gbhjpqjiueknetsk")
    public suspend fun protocol(`value`: Output<Either<String, ApplicationGatewayProtocol>>) {
        this.protocol = value
    }

    /**
     * @param value The probe timeout in seconds. Probe marked as failed if valid response is not received with this timeout period. Acceptable values are from 1 second to 86400 seconds.
     */
    @JvmName("gaybyxwsnxynwnmq")
    public suspend fun timeout(`value`: Output<Int>) {
        this.timeout = value
    }

    /**
     * @param value The probe retry count. Backend server is marked down after consecutive probe failure count reaches UnhealthyThreshold. Acceptable values are from 1 second to 20.
     */
    @JvmName("pgkpgouyhppnmlir")
    public suspend fun unhealthyThreshold(`value`: Output<Int>) {
        this.unhealthyThreshold = value
    }

    /**
     * @param value Host name to send the probe to.
     */
    @JvmName("bkmkwlkxpbbtvvue")
    public suspend fun host(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.host = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("rafkfkojoyxpjwdw")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The probing interval in seconds. This is the time interval between two consecutive probes. Acceptable values are from 1 second to 86400 seconds.
     */
    @JvmName("wvjdstmcqmotnvry")
    public suspend fun interval(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.interval = mapped
    }

    /**
     * @param value Criterion for classifying a healthy probe response.
     */
    @JvmName("frbdljnhbuocpfwr")
    public suspend fun match(`value`: ApplicationGatewayProbeHealthResponseMatchArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.match = mapped
    }

    /**
     * @param argument Criterion for classifying a healthy probe response.
     */
    @JvmName("sybqtyckqdbsikea")
    public suspend
    fun match(argument: suspend ApplicationGatewayProbeHealthResponseMatchArgsBuilder.() -> Unit) {
        val toBeMapped = ApplicationGatewayProbeHealthResponseMatchArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.match = mapped
    }

    /**
     * @param value Minimum number of servers that are always marked healthy. Default value is 0.
     */
    @JvmName("cdxwslathnnjouxm")
    public suspend fun minServers(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minServers = mapped
    }

    /**
     * @param value Name of the probe that is unique within an Application Gateway.
     */
    @JvmName("lfcucmqlbaleyjhr")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Relative path of probe. Valid path starts from '/'. Probe is sent to <Protocol>://<host>:<port><path>.
     */
    @JvmName("snytwoqnvitflyyc")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value Whether the host header should be picked from the backend http settings. Default value is false.
     */
    @JvmName("kowpyeisvtqxjmvi")
    public suspend fun pickHostNameFromBackendHttpSettings(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pickHostNameFromBackendHttpSettings = mapped
    }

    /**
     * @param value Whether the server name indication should be picked from the backend settings for Tls protocol. Default value is false.
     */
    @JvmName("cmgrjedtjfikajbq")
    public suspend fun pickHostNameFromBackendSettings(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pickHostNameFromBackendSettings = mapped
    }

    /**
     * @param value Custom port which will be used for probing the backend servers. The valid value ranges from 1 to 65535. In case not set, port from http settings will be used. This property is valid for Standard_v2 and WAF_v2 only.
     */
    @JvmName("xcgabomntmwdcgbb")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value The protocol used for the probe.
     */
    @JvmName("mfowreykulomnyuc")
    public suspend fun protocol(`value`: Either<String, ApplicationGatewayProtocol>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value The protocol used for the probe.
     */
    @JvmName("uadihiylqinfclee")
    public fun protocol(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ApplicationGatewayProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value The protocol used for the probe.
     */
    @JvmName("cjvwxymuddwmcswd")
    public fun protocol(`value`: ApplicationGatewayProtocol) {
        val toBeMapped = Either.ofRight<String, ApplicationGatewayProtocol>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    /**
     * @param value The probe timeout in seconds. Probe marked as failed if valid response is not received with this timeout period. Acceptable values are from 1 second to 86400 seconds.
     */
    @JvmName("hrrtwbuvrycbbrvs")
    public suspend fun timeout(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeout = mapped
    }

    /**
     * @param value The probe retry count. Backend server is marked down after consecutive probe failure count reaches UnhealthyThreshold. Acceptable values are from 1 second to 20.
     */
    @JvmName("uqofmdbsjuivkuyu")
    public suspend fun unhealthyThreshold(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.unhealthyThreshold = mapped
    }

    internal fun build(): ApplicationGatewayProbeArgs = ApplicationGatewayProbeArgs(
        host = host,
        id = id,
        interval = interval,
        match = match,
        minServers = minServers,
        name = name,
        path = path,
        pickHostNameFromBackendHttpSettings = pickHostNameFromBackendHttpSettings,
        pickHostNameFromBackendSettings = pickHostNameFromBackendSettings,
        port = port,
        protocol = protocol,
        timeout = timeout,
        unhealthyThreshold = unhealthyThreshold,
    )
}
